.. currentmodule:: pysdic.blender

Blender Material BSDF Class and default Materials
==================================================================

.. contents:: Table of Contents
    :local:
    :depth: 2

Main Class
---------------

.. autoclass:: BlenderMaterialBSDF
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

Default Materials
-------------------------

.. autofunction:: get_mirror_material

.. autofunction:: get_steel_material

.. autofunction:: get_titanium_material

.. autofunction:: get_iron_material

.. autofunction:: get_copper_material
